diff --git a/dune/solvers/iterationsteps/minimalpolynomialextrapolationstep.hh b/dune/solvers/iterationsteps/minimalpolynomialextrapolationstep.hh
index e23cb3ab903155c6b5c681de7c1c69263834a8b4..c1b7ffd353b9751623ed91e927108c2575709080 100644
--- a/dune/solvers/iterationsteps/minimalpolynomialextrapolationstep.hh
+++ b/dune/solvers/iterationsteps/minimalpolynomialextrapolationstep.hh
@@ -121,7 +121,7 @@ void MinimalPolynomialExtrapolationStep<VectorType, BitVectorType>::iterate()
     Dune::MatrixAdapter<ScalarMatrixType,ScalarVectorType,ScalarVectorType> op(UTU);
 
     // A preconditioner
-    Dune::SeqILU0<ScalarMatrixType,ScalarVectorType,ScalarVectorType> ilu0(UTU,1.0);
+    Dune::SeqILU<ScalarMatrixType,ScalarVectorType,ScalarVectorType> ilu0(UTU, 0, 1.0);
 
     // A preconditioned conjugate-gradient solver
     Dune::CGSolver<ScalarVectorType> cg(op,ilu0,1e-6,  // tolerance
diff --git a/dune/solvers/iterationsteps/istlseqilu0step.hh b/dune/solvers/iterationsteps/istlseqilu0step.hh
index 0a714ff5334a86040f591bbbbb9313c24887ccc6..1832f4a170b2100f42d71b66a0305d2eeedf0491 100644
--- a/dune/solvers/iterationsteps/istlseqilu0step.hh
+++ b/dune/solvers/iterationsteps/istlseqilu0step.hh
@@ -4,7 +4,7 @@
 #define ISTL_SEQILU0_STEP_HH
 
 /** \file
-    \brief A wrapper class for the ISTL SeqILU0 implementation
+    \brief A wrapper class for the ISTL SeqILU(0) implementation
  */
 
 #include <memory>
@@ -13,14 +13,14 @@
 
 #include <dune/istl/preconditioners.hh>
 
 /** \brief A wrapper class for the ISTL SeqILU0 implementation
  */
 template <class MatrixType, class VectorType>
 class ISTLSeqILU0Step
     // FIXME: ignoreNodes are not handled
     : public LinearIterationStep<MatrixType, VectorType>
 {
-    typedef Dune::SeqILU0<MatrixType,VectorType,VectorType> SeqILU0;
+    typedef Dune::SeqILU<MatrixType,VectorType,VectorType> SeqILU0;
 
 public:
     ISTLSeqILU0Step (double relaxationFactor)
@@ -31,7 +31,7 @@ public:
      */
     virtual void preprocess() override {
         if (needReconstruction_) {
-            seqILU0_ = std::make_unique<SeqILU0>(*this->mat_, relaxationFactor_);
+            seqILU0_ = std::make_unique<SeqILU>(*this->mat_, 0, relaxationFactor_);
             needReconstruction_ = false;
         }
         // Note: as of now, pre() is a dummy
@@ -13,14 +13,14 @@
 #include <dune/istl/preconditioners.hh>
 
-/** \brief A wrapper class for the ISTL SeqILU0 implementation
+/** \brief A wrapper class for the ISTL SeqILU(0) implementation
  */
 template <class MatrixType, class VectorType>